Class: Google::Cloud::Video::LiveStream::V1::Asset
- Inherits:
-
Object
- Object
- Google::Cloud::Video::LiveStream::V1::Asset
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/video/livestream/v1/resources.rb
Overview
An asset represents a video or an image.
Defined Under Namespace
Modules: State Classes: ImageAsset, LabelsEntry, VideoAsset
Instance Attribute Summary collapse
-
#crc32c ⇒ ::String
Based64-encoded CRC32c checksum of the asset file.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#error ⇒ ::Google::Rpc::Status
readonly
Output only.
-
#image ⇒ ::Google::Cloud::Video::LiveStream::V1::Asset::ImageAsset
ImageAsset represents an image.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
User-defined key/value metadata.
-
#name ⇒ ::String
The resource name of the asset, in the form of:
projects/{project}/locations/{location}/assets/{assetId}. -
#state ⇒ ::Google::Cloud::Video::LiveStream::V1::Asset::State
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#video ⇒ ::Google::Cloud::Video::LiveStream::V1::Asset::VideoAsset
VideoAsset represents a video.
Instance Attribute Details
#crc32c ⇒ ::String
Returns Based64-encoded CRC32c checksum of the asset file. For more information, see the crc32c checksum of the Cloud Storage Objects resource. If crc32c is omitted or left empty when the asset is created, this field is filled by the crc32c checksum of the Cloud Storage object indicated by VideoAsset.uri or ImageAsset.uri. If crc32c is set, the asset can't be created if the crc32c value does not match with the crc32c checksum of the Cloud Storage object indicated by VideoAsset.uri or ImageAsset.uri.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The creation time.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#error ⇒ ::Google::Rpc::Status (readonly)
Returns Output only. Only present when state is ERROR. The reason for the error
state of the asset.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#image ⇒ ::Google::Cloud::Video::LiveStream::V1::Asset::ImageAsset
Returns ImageAsset represents an image.
Note: The following fields are mutually exclusive: image, video. If a field in that set is populated, all other fields in the set will automatically be cleared.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns User-defined key/value metadata.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#name ⇒ ::String
Returns The resource name of the asset, in the form of:
projects/{project}/locations/{location}/assets/{assetId}.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#state ⇒ ::Google::Cloud::Video::LiveStream::V1::Asset::State (readonly)
Returns Output only. The state of the asset resource.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The update time.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |
#video ⇒ ::Google::Cloud::Video::LiveStream::V1::Asset::VideoAsset
Returns VideoAsset represents a video.
Note: The following fields are mutually exclusive: video, image. If a field in that set is populated, all other fields in the set will automatically be cleared.
1069 1070 1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 1091 1092 1093 1094 1095 1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 1106 1107 1108 1109 1110 1111 1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'proto_docs/google/cloud/video/livestream/v1/resources.rb', line 1069 class Asset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # VideoAsset represents a video. The supported formats are MP4, MPEG-TS, and # FLV. The supported video codec is H264. The supported audio codecs are # AAC, AC3, MP2, and MP3. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the video. The format is `gs://my-bucket/my-object`. class VideoAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Image represents an image. The supported formats are JPEG, PNG. # @!attribute [rw] uri # @return [::String] # Cloud Storage URI of the image. The format is `gs://my-bucket/my-object`. class ImageAsset include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # State of the asset resource. module State # State is not specified. STATE_UNSPECIFIED = 0 # The asset is being created. CREATING = 1 # The asset is ready for use. ACTIVE = 2 # The asset is being deleted. DELETING = 3 # The asset has an error. ERROR = 4 end end |